@@ -1,2 +1,5 @@
 # -*- coding: utf-8 -*-
 from munin.plugin import Field, Plugin
+
+Field = Field
+Plugin = Plugin
