@@ -1,6 +1,8 @@
 # -*- coding: utf-8 -*-
 import inflection
+import inspect
 import os
+import six
 import sys
 
 class Plugin(object):
@@ -24,11 +26,19 @@ class Plugin(object):
         print('graph_category ' + self.category)
         print('graph_vlabel ' + self.vlabel)
         for field in self.fields:
+            if isinstance(field, six.string_types):
+                field = Field(field)
             field.config()
     
     def execute(self):
         values = self.values()
-        lines = ['%s.value %s' % (k, v) for k, v in values.items()]
+        if isinstance(values, dict):
+            values = values.items()
+        elif hasattr(values, '__iter__'):
+            values = list(values)
+        else:
+            raise Exception('Values type "%s" is not supported.' % type(values).__name__)
+        lines = ['%s.value %0.3f' % (k, v) for k, v in values]
         lines.sort()
         print('\n'.join(lines))
     
